@@ -1,6 +1,6 @@
 /***************************************************************************
     begin                : Thu Oct 28 2004
-    copyright            : (C) 2004 by Michael Pyne
+    copyright            : (C) 2004, 2007, 2009 by Michael Pyne
                          : (c) 2003 Frerich Raabe <raabe@kde.org>
     email                : michael.pyne@kdemail.net
 ***************************************************************************/
@@ -14,83 +14,87 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "filerenamer.h"
+
 #include <algorithm>
 
 #include <kdebug.h>
-#include <kcombobox.h>
 #include <kurl.h>
 #include <kurlrequester.h>
 #include <kiconloader.h>
 #include <knuminput.h>
 #include <kstandarddirs.h>
+#include <kio/job.h>
 #include <kio/netaccess.h>
-#include <kconfigbase.h>
-#include <kconfig.h>
+#include <kdesktopfile.h>
+#include <kconfiggroup.h>
 #include <kglobal.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <kapplication.h>
 #include <kmessagebox.h>
-#include <ksimpleconfig.h>
+#include <kvbox.h>
 
-#include <qfile.h>
-#include <qhbox.h>
-#include <qvbox.h>
-#include <qscrollview.h>
-#include <qobjectlist.h>
-#include <qtimer.h>
-#include <qregexp.h>
-#include <qcheckbox.h>
-#include <qdir.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qsignalmapper.h>
-#include <qheader.h>
+#include <QFile>
+#include <QTimer>
+#include <QCheckBox>
+#include <QDir>
+#include <QLabel>
+#include <QSignalMapper>
+#include <QPixmap>
+#include <QFrame>
+#include <Q3Header>
 
 #include "tag.h"
+#include "filerenameroptions.h"
 #include "filehandle.h"
-#include "filerenamer.h"
 #include "exampleoptions.h"
 #include "playlistitem.h"
-#include "playlist.h"
+#include "playlist.h" // processEvents()
 #include "coverinfo.h"
 
-class ConfirmationDialog : public KDialogBase
+class ConfirmationDialog : public KDialog
 {
 public:
     ConfirmationDialog(const QMap<QString, QString> &files,
                        QWidget *parent = 0, const char *name = 0)
-        : KDialogBase(parent, name, true, i18n("Warning"), Ok | Cancel)
+        : KDialog(parent)
     {
-        QVBox *vbox = makeVBoxMainWidget();
-        QHBox *hbox = new QHBox(vbox);
+        setObjectName(name);
+        setModal(true);
+        setCaption(i18nc("warning about mass file rename", "Warning"));
+        setButtons(Ok | Cancel);
+
+        KVBox *vbox = new KVBox(this);
+        setMainWidget(vbox);
+        KVBox *hbox = new KVBox(vbox);
 
         QLabel *l = new QLabel(hbox);
-        l->setPixmap(SmallIcon("messagebox_warning", 32));
+        l->setPixmap(SmallIcon("dialog-warning", 32));
 
         l = new QLabel(i18n("You are about to rename the following files. "
                             "Are you sure you want to continue?"), hbox);
         hbox->setStretchFactor(l, 1);
 
-        KListView *lv = new KListView(vbox);
+        K3ListView *lv = new K3ListView(vbox);
 
         lv->addColumn(i18n("Original Name"));
         lv->addColumn(i18n("New Name"));
 
         int lvHeight = 0;
 
-        QMap<QString, QString>::ConstIterator it = files.begin();
-        for(; it != files.end(); ++it) {
-            KListViewItem *i = it.key() != it.data()
-                ? new KListViewItem(lv, it.key(), it.data())
-                : new KListViewItem(lv, it.key(), i18n("No Change"));
+        QMap<QString, QString>::ConstIterator it = files.constBegin();
+        for(; it != files.constEnd(); ++it) {
+            K3ListViewItem *i = it.key() != it.value()
+                ? new K3ListViewItem(lv, it.key(), it.value())
+                : new K3ListViewItem(lv, it.key(), i18n("No Change"));
             lvHeight += i->height();
         }
 
         lvHeight += lv->horizontalScrollBar()->height() + lv->header()->height();
-        lv->setMinimumHeight(QMIN(lvHeight, 400));
-        resize(QMIN(width(), 500), QMIN(minimumHeight(), 400));
+        lv->setMinimumHeight(qMin(lvHeight, 400));
+        resize(qMin(width(), 500), qMin(minimumHeight(), 400));
     }
 };
 
@@ -103,18 +107,18 @@ ConfigCategoryReader::ConfigCategoryReader() : CategoryReaderInterface(),
 {
     KConfigGroup config(KGlobal::config(), "FileRenamer");
 
-    QValueList<int> categoryOrder = config.readIntListEntry("CategoryOrder");
-    unsigned categoryCount[NumTypes] = { 0 }; // Keep track of each category encountered.
+    QList<int> categoryOrder = config.readEntry("CategoryOrder", QList<int>());
+    int categoryCount[NumTypes] = { 0 }; // Keep track of each category encountered.
 
     // Set a default:
 
     if(categoryOrder.isEmpty())
         categoryOrder << Artist << Album << Title << Track;
 
-    QValueList<int>::ConstIterator catIt = categoryOrder.constBegin();
+    QList<int>::ConstIterator catIt = categoryOrder.constBegin();
     for(; catIt != categoryOrder.constEnd(); ++catIt)
     {
-        unsigned catCount = categoryCount[*catIt]++;
+        int catCount = categoryCount[*catIt]++;
         TagType category = static_cast<TagType>(*catIt);
         CategoryID catId(category, catCount);
 
@@ -122,15 +126,14 @@ ConfigCategoryReader::ConfigCategoryReader() : CategoryReaderInterface(),
         m_categoryOrder << catId;
     }
 
-    m_folderSeparators.resize(m_categoryOrder.count() - 1, false);
+    m_folderSeparators.fill(false, m_categoryOrder.count() - 1);
 
-    QValueList<int> checkedSeparators = config.readIntListEntry("CheckedDirSeparators");
+    QList<int> checkedSeparators = config.readEntry("CheckedDirSeparators", QList<int>());
 
-    QValueList<int>::ConstIterator it = checkedSeparators.constBegin();
+    QList<int>::ConstIterator it = checkedSeparators.constBegin();
     for(; it != checkedSeparators.constEnd(); ++it) {
-        unsigned index = static_cast<unsigned>(*it);
-        if(index < m_folderSeparators.count())
-            m_folderSeparators[index] = true;
+        if(*it < m_folderSeparators.count())
+            m_folderSeparators[*it] = true;
     }
 
     m_musicFolder = config.readPathEntry("MusicFolder", "${HOME}/music");
@@ -140,7 +143,7 @@ ConfigCategoryReader::ConfigCategoryReader() : CategoryReaderInterface(),
 QString ConfigCategoryReader::categoryValue(TagType type) const
 {
     if(!m_currentItem)
-        return QString::null;
+        return QString();
 
     Tag *tag = m_currentItem->file().tag();
 
@@ -164,7 +167,7 @@ QString ConfigCategoryReader::categoryValue(TagType type) const
         return tag->genre();
 
     default:
-        return QString::null;
+        return QString();
     }
 }
 
@@ -188,7 +191,7 @@ QString ConfigCategoryReader::emptyText(const CategoryID &category) const
     return m_options[category].emptyText();
 }
 
-QValueList<CategoryID> ConfigCategoryReader::categoryOrder() const
+QList<CategoryID> ConfigCategoryReader::categoryOrder() const
 {
     return m_categoryOrder;
 }
@@ -203,12 +206,12 @@ QString ConfigCategoryReader::musicFolder() const
     return m_musicFolder;
 }
 
-int ConfigCategoryReader::trackWidth(unsigned categoryNum) const
+int ConfigCategoryReader::trackWidth(int categoryNum) const
 {
     return m_options[CategoryID(Track, categoryNum)].trackWidth();
 }
 
-bool ConfigCategoryReader::hasFolderSeparator(unsigned index) const
+bool ConfigCategoryReader::hasFolderSeparator(int index) const
 {
     if(index >= m_folderSeparators.count())
         return false;
@@ -225,15 +228,13 @@ bool ConfigCategoryReader::isDisabled(const CategoryID &category) const
 //
 
 FileRenamerWidget::FileRenamerWidget(QWidget *parent) :
-    FileRenamerBase(parent), CategoryReaderInterface(),
+    QWidget(parent),
+    CategoryReaderInterface(),
+    m_ui(new Ui::FileRenamerBase),
     m_exampleFromFile(false)
 {
-    QLabel *temp = new QLabel(0);
-    m_exampleText->setPaletteBackgroundColor(temp->paletteBackgroundColor());
-    delete temp;
+    m_ui->setupUi(this);
 
-    layout()->setMargin(0); // We'll be wrapped by KDialogBase
-    
     // This must be created before createTagRows() is called.
 
     m_exampleDialog = new ExampleOptionsDialog(this);
@@ -242,10 +243,10 @@ FileRenamerWidget::FileRenamerWidget(QWidget *parent) :
     loadConfig();
 
     // Add correct text to combo box.
-    m_category->clear();
-    for(unsigned i = StartTag; i < NumTypes; ++i) {
+    m_ui->m_category->clear();
+    for(int i = StartTag; i < NumTypes; ++i) {
         QString category = TagRenamerOptions::tagTypeText(static_cast<TagType>(i));
-        m_category->insertItem(category);
+        m_ui->m_category->addItem(category);
     }
 
     connect(m_exampleDialog, SIGNAL(signalShown()), SLOT(exampleDialogShown()));
@@ -259,47 +260,45 @@ FileRenamerWidget::FileRenamerWidget(QWidget *parent) :
 
 void FileRenamerWidget::loadConfig()
 {
-    QValueList<int> checkedSeparators;
+    QList<int> checkedSeparators;
     KConfigGroup config(KGlobal::config(), "FileRenamer");
 
-    for(unsigned i = 0; i < m_rows.count(); ++i)
+    for(int i = 0; i < m_rows.count(); ++i)
         m_rows[i].options = TagRenamerOptions(m_rows[i].category);
 
-    checkedSeparators = config.readIntListEntry("CheckedDirSeparators");
+    checkedSeparators = config.readEntry("CheckedDirSeparators", QList<int>());
 
-    QValueList<int>::ConstIterator it = checkedSeparators.begin();
-    for(; it != checkedSeparators.end(); ++it) {
-        unsigned separator = static_cast<unsigned>(*it);
+    foreach(int separator, checkedSeparators) {
         if(separator < m_folderSwitches.count())
             m_folderSwitches[separator]->setChecked(true);
     }
 
-    QString url = config.readPathEntry("MusicFolder", "${HOME}/music");
-    m_musicFolder->setURL(url);
+    QString path = config.readEntry("MusicFolder", "${HOME}/music");
+    m_ui->m_musicFolder->setPath(path);
 
-    m_separator->setCurrentText(config.readEntry("Separator", " - "));
+    m_ui->m_separator->setEditText(config.readEntry("Separator", " - "));
 }
 
 void FileRenamerWidget::saveConfig()
 {
     KConfigGroup config(KGlobal::config(), "FileRenamer");
-    QValueList<int> checkedSeparators;
-    QValueList<int> categoryOrder;
+    QList<int> checkedSeparators;
+    QList<int> categoryOrder;
 
-    for(unsigned i = 0; i < m_rows.count(); ++i) {
-        unsigned rowId = idOfPosition(i); // Write out in GUI order, not m_rows order
+    for(int i = 0; i < m_rows.count(); ++i) {
+        int rowId = idOfPosition(i); // Write out in GUI order, not m_rows order
         m_rows[rowId].options.saveConfig(m_rows[rowId].category.categoryNumber);
         categoryOrder += m_rows[rowId].category.category;
     }
 
-    for(unsigned i = 0; i < m_folderSwitches.count(); ++i)
+    for(int i = 0; i < m_folderSwitches.count(); ++i)
         if(m_folderSwitches[i]->isChecked() == true)
             checkedSeparators += i;
 
     config.writeEntry("CheckedDirSeparators", checkedSeparators);
     config.writeEntry("CategoryOrder", categoryOrder);
-    config.writePathEntry("MusicFolder", m_musicFolder->url());
-    config.writeEntry("Separator", m_separator->currentText());
+    config.writePathEntry("MusicFolder", m_ui->m_musicFolder->url().path());
+    config.writeEntry("Separator", m_ui->m_separator->currentText());
 
     config.sync();
 }
@@ -308,14 +307,14 @@ FileRenamerWidget::~FileRenamerWidget()
 {
 }
 
-unsigned FileRenamerWidget::addRowCategory(TagType category)
+int FileRenamerWidget::addRowCategory(TagType category)
 {
-    static QPixmap up   = SmallIcon("up");
-    static QPixmap down = SmallIcon("down");
+    static QIcon up   = SmallIcon("go-up");
+    static QIcon down = SmallIcon("go-down");
 
     // Find number of categories already of this type.
-    unsigned categoryCount = 0;
-    for(unsigned i = 0; i < m_rows.count(); ++i)
+    int categoryCount = 0;
+    for(int i = 0; i < m_rows.count(); ++i)
         if(m_rows[i].category.category == category)
             ++categoryCount;
 
@@ -323,27 +322,30 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
 
     row.category = CategoryID(category, categoryCount);
     row.position = m_rows.count();
-    unsigned id = row.position;
+    int id = row.position;
 
-    QHBox *frame = new QHBox(m_mainFrame);
-    frame->setPaletteBackgroundColor(frame->paletteBackgroundColor().dark(110));
+    QFrame *frame = new QFrame(m_mainFrame);
+    QHBoxLayout *frameLayout = new QHBoxLayout(frame);
+    frameLayout->setMargin(3);
 
     row.widget = frame;
     frame->setFrameShape(QFrame::Box);
     frame->setLineWidth(1);
-    frame->setMargin(3);
 
-    m_mainFrame->setStretchFactor(frame, 1);
+    QBoxLayout *mainFrameLayout = static_cast<QBoxLayout *>(m_mainFrame->layout());
+    mainFrameLayout->addWidget(frame, 1);
 
-    QVBox *buttons = new QVBox(frame);
+    QFrame *buttons = new QFrame(frame);
+    QVBoxLayout *buttonLayout = new QVBoxLayout(buttons);
+    frameLayout->addWidget(buttons);
     buttons->setFrameStyle(QFrame::Plain | QFrame::Box);
     buttons->setLineWidth(1);
 
     row.upButton = new KPushButton(buttons);
     row.downButton = new KPushButton(buttons);
 
-    row.upButton->setPixmap(up);
-    row.downButton->setPixmap(down);
+    row.upButton->setIcon(up);
+    row.downButton->setIcon(down);
     row.upButton->setFlat(true);
     row.downButton->setFlat(true);
 
@@ -352,17 +354,24 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
     downMapper->connect(row.downButton, SIGNAL(clicked()), SLOT(map()));
     downMapper->setMapping(row.downButton, id);
 
+    buttonLayout->addWidget(row.upButton);
+    buttonLayout->addWidget(row.downButton);
+
     QString labelText = QString("<b>%1</b>").arg(TagRenamerOptions::tagTypeText(category));
     QLabel *label = new QLabel(labelText, frame);
-    frame->setStretchFactor(label, 1);
-    label->setAlignment(AlignCenter);
+    frameLayout->addWidget(label, 1);
+    label->setAlignment(Qt::AlignCenter);
 
-    QVBox *options = new QVBox(frame);
-    row.enableButton = new KPushButton(i18n("Remove"), options);
+    QVBoxLayout *optionLayout = new QVBoxLayout;
+    frameLayout->addLayout(optionLayout);
+
+    row.enableButton = new KPushButton(i18n("Remove"), frame);
+    optionLayout->addWidget(row.enableButton);
     toggleMapper->connect(row.enableButton, SIGNAL(clicked()), SLOT(map()));
     toggleMapper->setMapping(row.enableButton, id);
 
-    row.optionsButton = new KPushButton(i18n("Options"), options);
+    row.optionsButton = new KPushButton(i18n("Options"), frame);
+    optionLayout->addWidget(row.optionsButton);
     mapper->connect(row.optionsButton, SIGNAL(clicked()), SLOT(map()));
     mapper->setMapping(row.optionsButton, id);
 
@@ -371,12 +380,12 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
 
     // Disable add button if there's too many rows.
     if(m_rows.count() == MAX_CATEGORIES)
-        m_insertCategory->setEnabled(false);
+        m_ui->m_insertCategory->setEnabled(false);
 
     return id;
 }
 
-void FileRenamerWidget::moveSignalMappings(unsigned oldId, unsigned newId)
+void FileRenamerWidget::moveSignalMappings(int oldId, int newId)
 {
     mapper->setMapping(m_rows[oldId].optionsButton, newId);
     downMapper->setMapping(m_rows[oldId].downButton, newId);
@@ -384,15 +393,15 @@ void FileRenamerWidget::moveSignalMappings(unsigned oldId, unsigned newId)
     toggleMapper->setMapping(m_rows[oldId].enableButton, newId);
 }
 
-bool FileRenamerWidget::removeRow(unsigned id)
+bool FileRenamerWidget::removeRow(int id)
 {
     if(id >= m_rows.count()) {
-        kdWarning(65432) << "Trying to remove row, but " << id << " is out-of-range.\n";
+        kWarning(65432) << "Trying to remove row, but " << id << " is out-of-range.\n";
         return false;
     }
 
     if(m_rows.count() == 1) {
-        kdError(65432) << "Can't remove last row of File Renamer.\n";
+        kError(65432) << "Can't remove last row of File Renamer.\n";
         return false;
     }
 
@@ -404,7 +413,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
     m_rows[id].optionsButton = 0;
     m_rows[id].downButton = 0;
 
-    unsigned checkboxPosition = 0; // Remove first checkbox.
+    int checkboxPosition = 0; // Remove first checkbox.
 
     // If not the first row, remove the checkbox before it.
     if(m_rows[id].position > 0)
@@ -418,7 +427,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
     // Go through all the rows and if they have the same category and a
     // higher categoryNumber, decrement the number.  Also update the
     // position identifier.
-    for(unsigned i = 0; i < m_rows.count(); ++i) {
+    for(int i = 0; i < m_rows.count(); ++i) {
         if(i == id)
             continue; // Don't mess with ourself.
 
@@ -436,7 +445,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
     // Every row after the one we delete will have a different identifier, since
     // the identifier is simply its index into m_rows.  So we need to re-do the
     // signal mappings for the affected rows.
-    for(unsigned i = id + 1; i < m_rows.count(); ++i)
+    for(int i = id + 1; i < m_rows.count(); ++i)
         moveSignalMappings(i, i - 1);
 
     m_rows.erase(&m_rows[id]);
@@ -446,7 +455,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
     m_rows[idOfPosition(m_rows.count() - 1)].downButton->setEnabled(false);
 
     // We can insert another row now, make sure GUI is updated to match.
-    m_insertCategory->setEnabled(true);
+    m_ui->m_insertCategory->setEnabled(true);
 
     QTimer::singleShot(0, this, SLOT(exampleTextChanged()));
     return true;
@@ -455,11 +464,13 @@ bool FileRenamerWidget::removeRow(unsigned id)
 void FileRenamerWidget::addFolderSeparatorCheckbox()
 {
     QWidget *temp = new QWidget(m_mainFrame);
+    m_mainFrame->layout()->addWidget(temp);
+
     QHBoxLayout *l = new QHBoxLayout(temp);
 
     QCheckBox *cb = new QCheckBox(i18n("Insert folder separator"), temp);
     m_folderSwitches.append(cb);
-    l->addWidget(cb, 0, AlignCenter);
+    l->addWidget(cb, 0, Qt::AlignCenter);
     cb->setChecked(false);
 
     connect(cb, SIGNAL(toggled(bool)),
@@ -471,31 +482,36 @@ void FileRenamerWidget::addFolderSeparatorCheckbox()
 void FileRenamerWidget::createTagRows()
 {
     KConfigGroup config(KGlobal::config(), "FileRenamer");
-    QValueList<int> categoryOrder = config.readIntListEntry("CategoryOrder");
+    QList<int> categoryOrder = config.readEntry("CategoryOrder", QList<int>());
 
     if(categoryOrder.isEmpty())
-        categoryOrder << Artist << Album << Artist << Title << Track;
-    
+        categoryOrder << Artist << Album << Title << Track;
+
     // Setup arrays.
     m_rows.reserve(categoryOrder.count());
     m_folderSwitches.reserve(categoryOrder.count() - 1);
 
-    mapper       = new QSignalMapper(this, "signal mapper");
-    toggleMapper = new QSignalMapper(this, "toggle mapper");
-    upMapper     = new QSignalMapper(this, "up button mapper");
-    downMapper   = new QSignalMapper(this, "down button mapper");
+    mapper       = new QSignalMapper(this);
+    mapper->setObjectName("signal mapper");
+    toggleMapper = new QSignalMapper(this);
+    toggleMapper->setObjectName("toggle mapper");
+    upMapper     = new QSignalMapper(this);
+    upMapper->setObjectName("up button mapper");
+    downMapper   = new QSignalMapper(this);
+    downMapper->setObjectName("down button mapper");
 
     connect(mapper,       SIGNAL(mapped(int)), SLOT(showCategoryOption(int)));
     connect(toggleMapper, SIGNAL(mapped(int)), SLOT(slotRemoveRow(int)));
     connect(upMapper,     SIGNAL(mapped(int)), SLOT(moveItemUp(int)));
     connect(downMapper,   SIGNAL(mapped(int)), SLOT(moveItemDown(int)));
 
-    m_mainFrame = new QVBox(m_mainView->viewport());
-    m_mainFrame->setMargin(10);
-    m_mainFrame->setSpacing(5);
+    m_mainFrame = new QFrame(m_ui->m_mainView);
+    m_ui->m_mainView->setWidget(m_mainFrame);
+    m_ui->m_mainView->setWidgetResizable(true);
 
-    m_mainView->addChild(m_mainFrame);
-    m_mainView->setResizePolicy(QScrollView::AutoOneFit);
+    QVBoxLayout *frameLayout = new QVBoxLayout(m_mainFrame);
+    frameLayout->setMargin(10);
+    frameLayout->setSpacing(5);
 
     // OK, the deal with the categoryOrder variable is that we need to create
     // the rows in the order that they were saved in (the order given by categoryOrder).
@@ -503,16 +519,16 @@ void FileRenamerWidget::createTagRows()
     // a row given the identifier, use m_rows[id].position.  To find the id of a given
     // position, use idOfPosition(position).
 
-    QValueList<int>::ConstIterator it = categoryOrder.constBegin();
+    QList<int>::ConstIterator it = categoryOrder.constBegin();
 
     for(; it != categoryOrder.constEnd(); ++it) {
         if(*it < StartTag || *it >= NumTypes) {
-            kdError(65432) << "Invalid category encountered in file renamer configuration.\n";
+            kError(65432) << "Invalid category encountered in file renamer configuration.\n";
             continue;
         }
 
         if(m_rows.count() == MAX_CATEGORIES) {
-            kdError(65432) << "Maximum number of File Renamer tags reached, bailing.\n";
+            kError(65432) << "Maximum number of File Renamer tags reached, bailing.\n";
             break;
         }
 
@@ -523,7 +539,7 @@ void FileRenamerWidget::createTagRows()
         // Insert the directory separator checkbox if this isn't the last
         // item.
 
-        QValueList<int>::ConstIterator dup(it);
+        QList<int>::ConstIterator dup(it);
 
         // Check for last item
         if(++dup != categoryOrder.constEnd())
@@ -536,21 +552,20 @@ void FileRenamerWidget::createTagRows()
     // If we have maximum number of categories already, don't let the user
     // add more.
     if(m_rows.count() >= MAX_CATEGORIES)
-        m_insertCategory->setEnabled(false);
+        m_ui->m_insertCategory->setEnabled(false);
 }
 
 void FileRenamerWidget::exampleTextChanged()
 {
     // Just use .mp3 as an example
-
-    if(m_exampleFromFile && (m_exampleFile.isEmpty() || 
+    if(m_exampleFromFile && (m_exampleFile.isEmpty() ||
                              !FileHandle(m_exampleFile).tag()->isValid()))
     {
-        m_exampleText->setText(i18n("No file selected, or selected file has no tags."));
+        m_ui->m_exampleText->setText(i18n("No file selected, or selected file has no tags."));
         return;
     }
 
-    m_exampleText->setText(FileRenamer::fileName(*this) + ".mp3");
+    m_ui->m_exampleText->setText(FileRenamer::fileName(*this) + ".mp3");
 }
 
 QString FileRenamerWidget::fileCategoryValue(TagType category) const
@@ -578,7 +593,7 @@ QString FileRenamerWidget::fileCategoryValue(TagType category) const
         return tag->genre();
 
     default:
-        return QString::null;
+        return QString();
     }
 }
 
@@ -609,45 +624,44 @@ QString FileRenamerWidget::categoryValue(TagType category) const
         return example->m_exampleGenre->text();
 
     default:
-        return QString::null;
+        return QString();
     }
 }
 
-QValueList<CategoryID> FileRenamerWidget::categoryOrder() const
+QList<CategoryID> FileRenamerWidget::categoryOrder() const
 {
-    QValueList<CategoryID> list;
+    QList<CategoryID> list;
 
     // Iterate in GUI row order.
-    for(unsigned i = 0; i < m_rows.count(); ++i) {
-        unsigned rowId = idOfPosition(i);
-
+    for(int i = 0; i < m_rows.count(); ++i) {
+        int rowId = idOfPosition(i);
         list += m_rows[rowId].category;
     }
 
     return list;
 }
 
-bool FileRenamerWidget::hasFolderSeparator(unsigned index) const
+bool FileRenamerWidget::hasFolderSeparator(int index) const
 {
     if(index >= m_folderSwitches.count())
         return false;
     return m_folderSwitches[index]->isChecked();
 }
 
-void FileRenamerWidget::moveItem(unsigned id, MovementDirection direction)
+void FileRenamerWidget::moveItem(int id, MovementDirection direction)
 {
     QWidget *l = m_rows[id].widget;
-    unsigned bottom = m_rows.count() - 1;
-    unsigned pos = m_rows[id].position;
-    unsigned newPos = (direction == MoveUp) ? pos - 1 : pos + 1;
+    int bottom = m_rows.count() - 1;
+    int pos = m_rows[id].position;
+    int newPos = (direction == MoveUp) ? pos - 1 : pos + 1;
 
     // Item we're moving can't go further down after this.
 
     if((pos == (bottom - 1) && direction == MoveDown) ||
        (pos == bottom && direction == MoveUp))
     {
-        unsigned idBottomRow = idOfPosition(bottom);
-        unsigned idAboveBottomRow = idOfPosition(bottom - 1);
+        int idBottomRow = idOfPosition(bottom);
+        int idAboveBottomRow = idOfPosition(bottom - 1);
 
         m_rows[idBottomRow].downButton->setEnabled(true);
         m_rows[idAboveBottomRow].downButton->setEnabled(false);
@@ -656,8 +670,8 @@ void FileRenamerWidget::moveItem(unsigned id, MovementDirection direction)
     // We're moving the top item, do some button switching.
 
     if((pos == 0 && direction == MoveDown) || (pos == 1 && direction == MoveUp)) {
-        unsigned idTopItem = idOfPosition(0);
-        unsigned idBelowTopItem = idOfPosition(1);
+        int idTopItem = idOfPosition(0);
+        int idBelowTopItem = idOfPosition(1);
 
         m_rows[idTopItem].upButton->setEnabled(true);
         m_rows[idBelowTopItem].upButton->setEnabled(false);
@@ -665,7 +679,7 @@ void FileRenamerWidget::moveItem(unsigned id, MovementDirection direction)
 
     // This is the item we're swapping with.
 
-    unsigned idSwitchWith = idOfPosition(newPos);
+    int idSwitchWith = idOfPosition(newPos);
     QWidget *w = m_rows[idSwitchWith].widget;
 
     // Update the table of widget rows.
@@ -676,42 +690,44 @@ void FileRenamerWidget::moveItem(unsigned id, MovementDirection direction)
     // be 2 spaces because of the checkbox.
 
     QBoxLayout *layout = dynamic_cast<QBoxLayout *>(m_mainFrame->layout());
+    if ( !layout )
+        return;
 
-    layout->remove(l);
+    layout->removeWidget(l);
     layout->insertWidget(2 * newPos, l);
 
     // Move the top item two spaces in the opposite direction, for a similar
     // reason.
 
-    layout->remove(w);
+    layout->removeWidget(w);
     layout->insertWidget(2 * pos, w);
     layout->invalidate();
 
     QTimer::singleShot(0, this, SLOT(exampleTextChanged()));
 }
 
-unsigned FileRenamerWidget::idOfPosition(unsigned position) const
+int FileRenamerWidget::idOfPosition(int position) const
 {
     if(position >= m_rows.count()) {
-        kdError(65432) << "Search for position " << position << " out-of-range.\n";
-        return static_cast<unsigned>(-1);
+        kError(65432) << "Search for position " << position << " out-of-range.\n";
+        return -1;
     }
 
-    for(unsigned i = 0; i < m_rows.count(); ++i)
+    for(int i = 0; i < m_rows.count(); ++i)
         if(m_rows[i].position == position)
             return i;
 
-    kdError(65432) << "Unable to find identifier for position " << position << endl;
-    return static_cast<unsigned>(-1);
+    kError(65432) << "Unable to find identifier for position " << position << endl;
+    return -1;
 }
 
-unsigned FileRenamerWidget::findIdentifier(const CategoryID &category) const
+int FileRenamerWidget::findIdentifier(const CategoryID &category) const
 {
-    for(unsigned index = 0; index < m_rows.count(); ++index)
+    for(int index = 0; index < m_rows.count(); ++index)
         if(m_rows[index].category == category)
             return index;
 
-    kdError(65432) << "Unable to find match for category " <<
+    kError(65432) << "Unable to find match for category " <<
         TagRenamerOptions::tagTypeText(category.category) <<
         ", number " << category.categoryNumber << endl;
 
@@ -720,13 +736,13 @@ unsigned FileRenamerWidget::findIdentifier(const CategoryID &category) const
 
 void FileRenamerWidget::enableAllUpButtons()
 {
-    for(unsigned i = 0; i < m_rows.count(); ++i)
+    for(int i = 0; i < m_rows.count(); ++i)
         m_rows[i].upButton->setEnabled(true);
 }
 
 void FileRenamerWidget::enableAllDownButtons()
 {
-    for(unsigned i = 0; i < m_rows.count(); ++i)
+    for(int i = 0; i < m_rows.count(); ++i)
         m_rows[i].downButton->setEnabled(true);
 }
 
@@ -744,42 +760,42 @@ void FileRenamerWidget::showCategoryOption(int id)
 
 void FileRenamerWidget::moveItemUp(int id)
 {
-    moveItem(static_cast<unsigned>(id), MoveUp);
+    moveItem(id, MoveUp);
 }
 
 void FileRenamerWidget::moveItemDown(int id)
 {
-    moveItem(static_cast<unsigned>(id), MoveDown);
+    moveItem(id, MoveDown);
 }
 
 void FileRenamerWidget::toggleExampleDialog()
 {
-    m_exampleDialog->setShown(!m_exampleDialog->isShown());
+    m_exampleDialog->setHidden(!m_exampleDialog->isHidden());
 }
 
 void FileRenamerWidget::insertCategory()
 {
-    TagType category = TagRenamerOptions::tagFromCategoryText(m_category->currentText());
+    TagType category = TagRenamerOptions::tagFromCategoryText(m_ui->m_category->currentText());
     if(category == Unknown) {
-        kdError(65432) << "Trying to add unknown category somehow.\n";
+        kError(65432) << "Trying to add unknown category somehow.\n";
         return;
     }
 
     // We need to enable the down button of the current bottom row since it
     // can now move down.
-    unsigned idBottom = idOfPosition(m_rows.count() - 1);
+    int idBottom = idOfPosition(m_rows.count() - 1);
     m_rows[idBottom].downButton->setEnabled(true);
 
     addFolderSeparatorCheckbox();
 
     // Identifier of new row.
-    unsigned id = addRowCategory(category);
+    int id = addRowCategory(category);
 
     // Set its down button to be disabled.
     m_rows[id].downButton->setEnabled(false);
 
     m_mainFrame->layout()->invalidate();
-    m_mainView->update();
+    m_ui->m_mainView->update();
 
     // Now update according to the code in loadConfig().
     m_rows[id].options = TagRenamerOptions(m_rows[id].category);
@@ -788,12 +804,12 @@ void FileRenamerWidget::insertCategory()
 
 void FileRenamerWidget::exampleDialogShown()
 {
-    m_showExample->setText(i18n("Hide Renamer Test Dialog"));
+    m_ui->m_showExample->setText(i18n("Hide Renamer Test Dialog"));
 }
 
 void FileRenamerWidget::exampleDialogHidden()
 {
-    m_showExample->setText(i18n("Show Renamer Test Dialog"));
+    m_ui->m_showExample->setText(i18n("Show Renamer Test Dialog"));
 }
 
 void FileRenamerWidget::fileSelected(const QString &file)
@@ -811,19 +827,19 @@ void FileRenamerWidget::dataSelected()
 
 QString FileRenamerWidget::separator() const
 {
-    return m_separator->currentText();
+    return m_ui->m_separator->currentText();
 }
 
 QString FileRenamerWidget::musicFolder() const
 {
-    return m_musicFolder->url();
+    return m_ui->m_musicFolder->url().path();
 }
 
 void FileRenamerWidget::slotRemoveRow(int id)
 {
     // Remove the given identified row.
     if(!removeRow(id))
-        kdError(65432) << "Unable to remove row " << id << endl;
+        kError(65432) << "Unable to remove row " << id << endl;
 }
 
 //
@@ -849,11 +865,11 @@ void FileRenamer::rename(const PlaylistItemList &items)
     QMap<QString, QString> map;
     QMap<QString, PlaylistItem *> itemMap;
 
-    for(PlaylistItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
+    for(PlaylistItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
         reader.setPlaylistItem(*it);
         QString oldFile = (*it)->file().absFilePath();
-        QString extension = (*it)->file().fileInfo().extension(false);
-        QString newFile = fileName(reader) + "." + extension;
+        QString extension = (*it)->file().fileInfo().suffix();
+        QString newFile = fileName(reader) + '.' + extension;
 
         if(oldFile != newFile) {
             map[oldFile] = newFile;
@@ -865,17 +881,17 @@ void FileRenamer::rename(const PlaylistItemList &items)
         return;
 
     KApplication::setOverrideCursor(Qt::waitCursor);
-    for(QMap<QString, QString>::ConstIterator it = map.begin();
-        it != map.end(); ++it)
+    for(QMap<QString, QString>::ConstIterator it = map.constBegin();
+        it != map.constEnd(); ++it)
     {
-        if(moveFile(it.key(), it.data())) {
-            itemMap[it.key()]->setFile(it.data());
+        if(moveFile(it.key(), it.value())) {
+            itemMap[it.key()]->setFile(it.value());
             itemMap[it.key()]->refresh();
 
-            setFolderIcon(it.data(), itemMap[it.key()]);
+            setFolderIcon(it.value(), itemMap[it.key()]);
         }
         else
-            errorFiles << i18n("%1 to %2").arg(it.key()).arg(it.data());
+            errorFiles << i18n("%1 to %2", it.key(), it.value());
 
         processEvents();
     }
@@ -887,14 +903,14 @@ void FileRenamer::rename(const PlaylistItemList &items)
 
 bool FileRenamer::moveFile(const QString &src, const QString &dest)
 {
-    kdDebug(65432) << "Moving file " << src << " to " << dest << endl;
+    kDebug(65432) << "Moving file " << src << " to " << dest;
 
     if(src == dest)
         return false;
 
     // Escape URL.
-    KURL srcURL = KURL::fromPathOrURL(src);
-    KURL dstURL = KURL::fromPathOrURL(dest);
+    KUrl srcURL = KUrl(src);
+    KUrl dstURL = KUrl(dest);
 
     // Clean it.
     srcURL.cleanPath();
@@ -905,21 +921,22 @@ bool FileRenamer::moveFile(const QString &src, const QString &dest)
         return false;
 
     // Get just the directory.
-    KURL dir = dstURL;
-    dir.setFileName(QString::null);
+    KUrl dir = dstURL;
+    dir.setFileName(QString());
 
     // Create the directory.
     if(!KStandardDirs::exists(dir.path()))
         if(!KStandardDirs::makeDir(dir.path())) {
-            kdError() << "Unable to create directory " << dir.path() << endl;
+            kError() << "Unable to create directory " << dir.path() << endl;
             return false;
         }
 
     // Move the file.
-    return KIO::NetAccess::file_move(srcURL, dstURL);
+    KIO::Job *job = KIO::file_move(srcURL, dstURL);
+    return KIO::NetAccess::synchronousRun(job, 0);
 }
 
-void FileRenamer::setFolderIcon(const KURL &dst, const PlaylistItem *item)
+void FileRenamer::setFolderIcon(const KUrl &dst, const PlaylistItem *item)
 {
     if(item->file().tag()->album().isEmpty() ||
        !item->file().coverInfo()->hasCover())
@@ -927,33 +944,33 @@ void FileRenamer::setFolderIcon(const KURL &dst, const PlaylistItem *item)
         return;
     }
 
-    KURL dstURL = dst;
+    KUrl dstURL = dst;
     dstURL.cleanPath();
 
     // Split path, and go through each path element.  If a path element has
     // the album information, set its folder icon.
-    QStringList elements = QStringList::split("/", dstURL.directory());
+    QStringList elements = dstURL.directory().split("/", QString::SkipEmptyParts);
     QString path;
 
-    for(QStringList::ConstIterator it = elements.begin(); it != elements.end(); ++it) {
-        path.append("/" + (*it));
+    for(QStringList::ConstIterator it = elements.constBegin(); it != elements.constEnd(); ++it) {
+        path.append('/' + (*it));
 
-        kdDebug() << "Checking path: " << path << endl;
-        if((*it).find(item->file().tag()->album()) != -1 &&
+        kDebug() << "Checking path: " << path;
+        if((*it).contains(item->file().tag()->album() ) &&
            !QFile::exists(path + "/.directory"))
         {
             // Seems to be a match, let's set the folder icon for the current
             // path.  First we should write out the file.
-            
+
             QPixmap thumb = item->file().coverInfo()->pixmap(CoverInfo::Thumbnail);
             thumb.save(path + "/.juk-thumbnail.png", "PNG");
 
-            KSimpleConfig config(path + "/.directory");
-            config.setGroup("Desktop Entry");
+            KDesktopFile dirFile(path + "/.directory");
+            KConfigGroup desktopGroup(dirFile.desktopGroup());
 
-            if(!config.hasKey("Icon")) {
-                config.writeEntry("Icon", QString("%1/.juk-thumbnail.png").arg(path));
-                config.sync();
+            if(!desktopGroup.hasKey("Icon")) {
+                desktopGroup.writePathEntry("Icon", QString("%1/.juk-thumbnail.png").arg(path));
+                dirFile.sync();
             }
 
             return;
@@ -965,11 +982,11 @@ void FileRenamer::setFolderIcon(const KURL &dst, const PlaylistItem *item)
  * Returns iterator pointing to the last item enabled in the given list with
  * a non-empty value (or is required to be included).
  */
-QValueList<CategoryID>::ConstIterator lastEnabledItem(const QValueList<CategoryID> &list,
-                                                   const CategoryReaderInterface &interface)
+QList<CategoryID>::ConstIterator lastEnabledItem(const QList<CategoryID> &list,
+                                                 const CategoryReaderInterface &interface)
 {
-    QValueList<CategoryID>::ConstIterator it = list.constBegin();
-    QValueList<CategoryID>::ConstIterator last = list.constEnd();
+    QList<CategoryID>::ConstIterator it = list.constBegin();
+    QList<CategoryID>::ConstIterator last = list.constEnd();
 
     for(; it != list.constEnd(); ++it) {
         if(interface.isRequired(*it) || (!interface.isDisabled(*it) &&
@@ -984,20 +1001,20 @@ QValueList<CategoryID>::ConstIterator lastEnabledItem(const QValueList<CategoryI
 
 QString FileRenamer::fileName(const CategoryReaderInterface &interface)
 {
-    const QValueList<CategoryID> categoryOrder = interface.categoryOrder();
+    const QList<CategoryID> categoryOrder = interface.categoryOrder();
     const QString separator = interface.separator();
     const QString folder = interface.musicFolder();
-    QValueList<CategoryID>::ConstIterator lastEnabled;
-    unsigned i = 0;
+    QList<CategoryID>::ConstIterator lastEnabled;
+    int i = 0;
     QStringList list;
-    QChar dirSeparator = QChar(QDir::separator());
+    QChar dirSeparator (QDir::separator());
 
     // Use lastEnabled to properly handle folder separators.
     lastEnabled = lastEnabledItem(categoryOrder, interface);
     bool pastLast = false; // Toggles to true once we've passed lastEnabled.
 
-    for(QValueList<CategoryID>::ConstIterator it = categoryOrder.begin();
-            it != categoryOrder.end();
+    for(QList<CategoryID>::ConstIterator it = categoryOrder.constBegin();
+            it != categoryOrder.constEnd();
             ++it, ++i)
     {
         if(it == lastEnabled)
@@ -1044,4 +1061,4 @@ QString FileRenamer::fileName(const CategoryReaderInterface &interface)
 
 #include "filerenamer.moc"
 
-// vim: set et sw=4 ts=8:
+// vim: set et sw=4 tw=0 sta:
